@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "git-annex" "1.1"
+(define-package "git-annex" "20250626.2344"
   "Mode for easy editing of git-annex'd files."
   ()
   :url "https://github.com/jwiegley/git-annex-el"
-  :commit "7d41775a1709b5754a7779e9f64f15d336ea5c8c"
-  :revdesc "v1.1-0-g7d41775a1709"
+  :commit "7f12f0acb2548e22946c17b3cdd58a3376434294"
+  :revdesc "7f12f0acb254"
   :keywords '("files" "data" "git" "annex")
   :authors '(("John Wiegley" . "jwiegley@gmail.com"))
   :maintainers '(("John Wiegley" . "jwiegley@gmail.com")))
